@@ -10,7 +10,7 @@ static const char* FILE_NAME = "Sys/IO/Flock";
 
 int32_t SPVM__Sys__IO__Flock__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "Sys::IO::Flock#new method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "Sys::IO::Flock#new method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -29,7 +29,7 @@ int32_t SPVM__Sys__IO__Flock__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Flock__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "Sys::IO::Flock#DESTROY method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "Sys::IO::Flock#DESTROY method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -48,7 +48,7 @@ int32_t SPVM__Sys__IO__Flock__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Flock__l_type(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "Sys::IO::Flock#l_type method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "Sys::IO::Flock#l_type method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -68,15 +68,16 @@ int32_t SPVM__Sys__IO__Flock__l_type(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Flock__set_l_type(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "Sys::IO::Flock#set_l_type method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "Sys::IO::Flock#set_l_type method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
   void* obj_self = stack[0].oval;
   
+  int16_t l_type = stack[1].ival;
+  
   struct flock* st_flock = env->get_pointer(env, stack, obj_self);
   
-  int16_t l_type = stack[1].ival;
   st_flock->l_type = l_type;
   
   return 0;
@@ -85,7 +86,7 @@ int32_t SPVM__Sys__IO__Flock__set_l_type(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Flock__l_whence(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "Sys::IO::Flock#l_whence method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "Sys::IO::Flock#l_whence method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -105,15 +106,16 @@ int32_t SPVM__Sys__IO__Flock__l_whence(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Flock__set_l_whence(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "Sys::IO::Flock#set_l_whence method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "Sys::IO::Flock#set_l_whence method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
   void* obj_self = stack[0].oval;
   
+  int16_t l_whence = stack[1].ival;
+  
   struct flock* st_flock = env->get_pointer(env, stack, obj_self);
   
-  int16_t l_whence = stack[1].ival;
   st_flock->l_whence = l_whence;
   
   return 0;
@@ -122,7 +124,7 @@ int32_t SPVM__Sys__IO__Flock__set_l_whence(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Flock__l_start(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "Sys::IO::Flock#l_start method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "Sys::IO::Flock#l_start method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -142,15 +144,16 @@ int32_t SPVM__Sys__IO__Flock__l_start(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Flock__set_l_start(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "Sys::IO::Flock#set_l_start method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "Sys::IO::Flock#set_l_start method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
   void* obj_self = stack[0].oval;
   
+  int64_t l_start = stack[1].lval;
+  
   struct flock* st_flock = env->get_pointer(env, stack, obj_self);
   
-  int64_t l_start = stack[1].lval;
   st_flock->l_start = l_start;
   
   return 0;
@@ -159,7 +162,7 @@ int32_t SPVM__Sys__IO__Flock__set_l_start(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Flock__l_len(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "Sys::IO::Flock#l_len method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "Sys::IO::Flock#l_len method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -179,15 +182,16 @@ int32_t SPVM__Sys__IO__Flock__l_len(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Flock__set_l_len(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "Sys::IO::Flock#set_l_len method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "Sys::IO::Flock#set_l_len method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
   void* obj_self = stack[0].oval;
   
+  int64_t l_len = stack[1].lval;
+  
   struct flock* st_flock = env->get_pointer(env, stack, obj_self);
   
-  int64_t l_len = stack[1].lval;
   st_flock->l_len = l_len;
   
   return 0;
@@ -196,7 +200,7 @@ int32_t SPVM__Sys__IO__Flock__set_l_len(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Flock__l_pid(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "Sys::IO::Flock#new method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "Sys::IO::Flock#new method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -216,15 +220,16 @@ int32_t SPVM__Sys__IO__Flock__l_pid(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Flock__set_l_pid(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "Sys::IO::Flock#new method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "Sys::IO::Flock#new method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
   void* obj_self = stack[0].oval;
   
+  int32_t l_pid = stack[1].ival;
+  
   struct flock* st_flock = env->get_pointer(env, stack, obj_self);
   
-  int32_t l_pid = stack[1].ival;
   st_flock->l_pid = l_pid;
   
   return 0;
