@@ -21,7 +21,7 @@ int32_t SPVM__Sys__Process__Constant__EXIT_FAILURE(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = EXIT_FAILURE;
   return 0;
 #else
-  env->die(env, stack, "EXIT_FAILURE is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "EXIT_FAILURE is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -33,7 +33,7 @@ int32_t SPVM__Sys__Process__Constant__EXIT_SUCCESS(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = EXIT_SUCCESS;
   return 0;
 #else
-  env->die(env, stack, "EXIT_SUCCESS is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "EXIT_SUCCESS is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -45,7 +45,7 @@ int32_t SPVM__Sys__Process__Constant__WNOHANG(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = WNOHANG;
   return 0;
 #else
-  env->die(env, stack, "WNOHANG is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "WNOHANG is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -57,7 +57,7 @@ int32_t SPVM__Sys__Process__Constant__WUNTRACED(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = WUNTRACED;
   return 0;
 #else
-  env->die(env, stack, "WUNTRACED is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "WUNTRACED is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -69,7 +69,7 @@ int32_t SPVM__Sys__Process__Constant__WCONTINUED(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = WCONTINUED;
   return 0;
 #else
-  env->die(env, stack, "WCONTINUED is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "WCONTINUED is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -81,7 +81,7 @@ int32_t SPVM__Sys__Process__Constant__PRIO_PROCESS(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = PRIO_PROCESS;
   return 0;
 #else
-  env->die(env, stack, "PRIO_PROCESS is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "PRIO_PROCESS is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -93,7 +93,7 @@ int32_t SPVM__Sys__Process__Constant__PRIO_USER(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = PRIO_USER;
   return 0;
 #else
-  env->die(env, stack, "PRIO_USER is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "PRIO_USER is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -105,7 +105,7 @@ int32_t SPVM__Sys__Process__Constant__PRIO_PGRP(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = PRIO_PGRP;
   return 0;
 #else
-  env->die(env, stack, "PRIO_PGRP is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "PRIO_PGRP is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
