@@ -62,13 +62,13 @@ int32_t SPVM__Sys__Socket__In6_addr__set_s6_addr(SPVM_ENV* env, SPVM_VALUE* stac
   void* obj_s6_addr = stack[1].oval;
   
   if (!obj_s6_addr) {
-    return env->die(env, stack, "The address $address must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The address $address must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t s6_addr_length = env->length(env, stack, obj_s6_addr);
   
   if (!(s6_addr_length < 16)) {
-    return env->die(env, stack, "The length of the address $address must be less than 16.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The length of the address $address must be less than 16.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* chp_s6_addr = env->get_chars(env, stack, obj_s6_addr);
