@@ -63,7 +63,7 @@ int32_t SPVM__Sys__Socket__Sockaddr__upgrade(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_addr = stack[0].oval;
   
   if (!obj_addr) {
-    return env->die(env, stack, "The address $addr must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die_v2(env, stack, "The address $addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
@@ -98,7 +98,7 @@ int32_t SPVM__Sys__Socket__Sockaddr__upgrade(SPVM_ENV* env, SPVM_VALUE* stack) {
       break;
     }
     default: {
-      return env->die(env, stack, "The address family %d is not available.", sa_family, __func__, FILE_NAME, __LINE__);
+      return env->die_v2(env, stack, "The address family %d is not available.", __func__, FILE_NAME, __LINE__, sa_family);
     }
   }
   
