@@ -14,7 +14,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCKS_PER_SEC(SPVM_ENV* env, SPVM_VALUE* sta
   stack[0].ival = CLOCKS_PER_SEC;
   return 0;
 #else
-  env->die(env, stack, "CLOCKS_PER_SEC is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCKS_PER_SEC is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -26,7 +26,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_BOOTTIME(SPVM_ENV* env, SPVM_VALUE* sta
   stack[0].ival = CLOCK_BOOTTIME;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_BOOTTIME is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_BOOTTIME is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -38,7 +38,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_HIGHRES(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = CLOCK_HIGHRES;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_HIGHRES is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_HIGHRES is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -50,7 +50,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = CLOCK_MONOTONIC;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_MONOTONIC is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_MONOTONIC is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -62,7 +62,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC_COARSE(SPVM_ENV* env, SPVM_VA
   stack[0].ival = CLOCK_MONOTONIC_COARSE;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_MONOTONIC_COARSE is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_MONOTONIC_COARSE is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -74,7 +74,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC_FAST(SPVM_ENV* env, SPVM_VALU
   stack[0].ival = CLOCK_MONOTONIC_FAST;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_MONOTONIC_FAST is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_MONOTONIC_FAST is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -86,7 +86,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC_PRECISE(SPVM_ENV* env, SPVM_V
   stack[0].ival = CLOCK_MONOTONIC_PRECISE;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_MONOTONIC_PRECISE is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_MONOTONIC_PRECISE is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -98,7 +98,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC_RAW(SPVM_ENV* env, SPVM_VALUE
   stack[0].ival = CLOCK_MONOTONIC_RAW;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_MONOTONIC_RAW is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_MONOTONIC_RAW is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -110,7 +110,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_PROCESS_CPUTIME_ID(SPVM_ENV* env, SPVM_
   stack[0].ival = CLOCK_PROCESS_CPUTIME_ID;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_PROCESS_CPUTIME_ID is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_PROCESS_CPUTIME_ID is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -122,7 +122,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_PROF(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = CLOCK_PROF;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_PROF is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_PROF is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -134,7 +134,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME(SPVM_ENV* env, SPVM_VALUE* sta
   stack[0].ival = CLOCK_REALTIME;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_REALTIME is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_REALTIME is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -146,7 +146,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME_COARSE(SPVM_ENV* env, SPVM_VAL
   stack[0].ival = CLOCK_REALTIME_COARSE;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_REALTIME_COARSE is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_REALTIME_COARSE is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -158,7 +158,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME_FAST(SPVM_ENV* env, SPVM_VALUE
   stack[0].ival = CLOCK_REALTIME_FAST;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_REALTIME_FAST is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_REALTIME_FAST is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -170,7 +170,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME_PRECISE(SPVM_ENV* env, SPVM_VA
   stack[0].ival = CLOCK_REALTIME_PRECISE;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_REALTIME_PRECISE is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_REALTIME_PRECISE is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -182,7 +182,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME_RAW(SPVM_ENV* env, SPVM_VALUE*
   stack[0].ival = CLOCK_REALTIME_RAW;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_REALTIME_RAW is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_REALTIME_RAW is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -194,7 +194,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_SECOND(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = CLOCK_SECOND;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_SECOND is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_SECOND is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -206,7 +206,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_SOFTTIME(SPVM_ENV* env, SPVM_VALUE* sta
   stack[0].ival = CLOCK_SOFTTIME;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_SOFTTIME is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_SOFTTIME is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -218,7 +218,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_THREAD_CPUTIME_ID(SPVM_ENV* env, SPVM_V
   stack[0].ival = CLOCK_THREAD_CPUTIME_ID;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_THREAD_CPUTIME_ID is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_THREAD_CPUTIME_ID is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -230,7 +230,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_TIMEOFDAY(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = CLOCK_TIMEOFDAY;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_TIMEOFDAY is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_TIMEOFDAY is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -242,7 +242,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = CLOCK_UPTIME;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_UPTIME is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_UPTIME is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -254,7 +254,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME_COARSE(SPVM_ENV* env, SPVM_VALUE
   stack[0].ival = CLOCK_UPTIME_COARSE;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_UPTIME_COARSE is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_UPTIME_COARSE is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -266,7 +266,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME_FAST(SPVM_ENV* env, SPVM_VALUE*
   stack[0].ival = CLOCK_UPTIME_FAST;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_UPTIME_FAST is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_UPTIME_FAST is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -278,7 +278,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME_PRECISE(SPVM_ENV* env, SPVM_VALU
   stack[0].ival = CLOCK_UPTIME_PRECISE;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_UPTIME_PRECISE is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_UPTIME_PRECISE is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -290,7 +290,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME_RAW(SPVM_ENV* env, SPVM_VALUE* s
   stack[0].ival = CLOCK_UPTIME_RAW;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_UPTIME_RAW is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_UPTIME_RAW is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -302,7 +302,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_VIRTUAL(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = CLOCK_VIRTUAL;
   return 0;
 #else
-  env->die(env, stack, "CLOCK_VIRTUAL is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "CLOCK_VIRTUAL is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -314,7 +314,7 @@ int32_t SPVM__Sys__Time__Constant__ITIMER_PROF(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = ITIMER_PROF;
   return 0;
 #else
-  env->die(env, stack, "ITIMER_PROF is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "ITIMER_PROF is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -326,7 +326,7 @@ int32_t SPVM__Sys__Time__Constant__ITIMER_REAL(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = ITIMER_REAL;
   return 0;
 #else
-  env->die(env, stack, "ITIMER_REAL is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "ITIMER_REAL is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -338,7 +338,7 @@ int32_t SPVM__Sys__Time__Constant__ITIMER_REALPROF(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = ITIMER_REALPROF;
   return 0;
 #else
-  env->die(env, stack, "ITIMER_REALPROF is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "ITIMER_REALPROF is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -350,7 +350,7 @@ int32_t SPVM__Sys__Time__Constant__ITIMER_VIRTUAL(SPVM_ENV* env, SPVM_VALUE* sta
   stack[0].ival = ITIMER_VIRTUAL;
   return 0;
 #else
-  env->die(env, stack, "ITIMER_VIRTUAL is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "ITIMER_VIRTUAL is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -362,7 +362,7 @@ int32_t SPVM__Sys__Time__Constant__TIMER_ABSTIME(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = TIMER_ABSTIME;
   return 0;
 #else
-  env->die(env, stack, "TIMER_ABSTIME is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die_v2(env, stack, "TIMER_ABSTIME is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
